@@ -14,9 +14,9 @@
 
 
 import json
+import networkx as nx
 
 from oslo_log import log
-from oslo_utils import encodeutils
 from oslo_utils.strutils import bool_from_string
 from osprofiler import profiler
 import pecan
@@ -33,6 +33,7 @@ from vitrage.datasources.transformer_base import CLUSTER_ID
 LOG = log.getLogger(__name__)
 
 
+# noinspection PyBroadException
 @profiler.trace_cls("topology controller",
                     info={}, hide_args=False, trace_private=False)
 class TopologyController(RootRestController):
@@ -77,22 +78,29 @@ class TopologyController(RootRestController):
                                                    root=root,
                                                    all_tenants=all_tenants)
             LOG.debug(graph_data)
-            graph = graph_data
+            graph = json.loads(graph_data)
             if graph_type == 'graph':
                 return graph
             if graph_type == 'tree':
-                node_id = CLUSTER_ID
-                if root:
+                if nx.__version__ >= '2.0':
+                    node_id = ''
                     for node in graph['nodes']:
-                        if node[VProps.VITRAGE_ID] == root:
-                            node_id = node[VProps.ID]
+                        if (root and node[VProps.VITRAGE_ID] == root) or \
+                                (not root and node[VProps.ID] == CLUSTER_ID):
+                            node_id = node[VProps.GRAPH_INDEX]
                             break
+                else:
+                    node_id = CLUSTER_ID
+                    if root:
+                        for node in graph['nodes']:
+                            if node[VProps.VITRAGE_ID] == root:
+                                node_id = node[VProps.ID]
+                                break
                 return RootRestController.as_tree(graph, node_id)
 
-        except Exception as e:
-            to_unicode = encodeutils.exception_to_unicode(e)
-            LOG.exception('failed to get topology %s ', to_unicode)
-            abort(404, to_unicode)
+        except Exception:
+            LOG.exception('failed to get topology.')
+            abort(404, 'Failed to get topology.')
 
     @staticmethod
     def _check_input_para(graph_type, depth, query, root, all_tenants):
