@@ -11,8 +11,6 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import gc
-import threading
 
 from oslo_log import log
 from osprofiler import profiler
@@ -39,15 +37,8 @@ class TopologyApis(EntityGraphApisBase):
     def __init__(self, entity_graph, conf):
         self.entity_graph = entity_graph
         self.conf = conf
-        self.lock = threading.Lock()
 
     def get_topology(self, ctx, graph_type, depth, query, root, all_tenants):
-        with self.lock:
-            gc.collect()
-            return self._get_topology(ctx, graph_type, depth, query, root,
-                                      all_tenants)
-
-    def _get_topology(self, ctx, graph_type, depth, query, root, all_tenants):
         LOG.debug("TopologyApis get_topology - root: %s, all_tenants=%s",
                   str(root), all_tenants)
 
@@ -164,7 +155,8 @@ class TopologyApis(EntityGraphApisBase):
         :type current_project_id: string
         :type is_admin_project: boolean
         """
-        for alarm in graph.vertices_iter(query_dict=ALARMS_ALL_QUERY):
+
+        for alarm in graph.get_vertices(query_dict=ALARMS_ALL_QUERY):
             if not alarm.get(VProps.PROJECT_ID, None):
                 cat_filter = {VProps.VITRAGE_CATEGORY: EntityCategory.RESOURCE}
                 resource_neighbors = \
@@ -184,7 +176,7 @@ class TopologyApis(EntityGraphApisBase):
     def _create_graph_of_connected_components(self, ga, tmp_graph, root):
         return ga.subgraph(self._topology_for_unrooted_graph(ga,
                                                              tmp_graph,
-                                                             root))
+                                                             root)).copy()
 
     def _topology_for_unrooted_graph(self, ga, subgraph, root):
         """Finds topology for unrooted subgraph
@@ -209,7 +201,7 @@ class TopologyApis(EntityGraphApisBase):
             ga.connected_component_subgraphs(subgraph)
 
         for component_subgraph in local_connected_component_subgraphs:
-            entities += component_subgraph.nodes()
+            entities += list(component_subgraph.nodes())
             instance_in_component_subgraph = \
                 self._find_instance_in_graph(component_subgraph)
             if instance_in_component_subgraph:
@@ -232,7 +224,7 @@ class TopologyApis(EntityGraphApisBase):
 
     @staticmethod
     def _find_instance_in_graph(graph):
-        for node, node_data in graph.nodes_iter(data=True):
+        for node, node_data in graph.nodes(data=True):
             if node_data[VProps.VITRAGE_CATEGORY] == \
                     EntityCategory.RESOURCE \
                     and node_data[VProps.VITRAGE_TYPE] == \
