@@ -14,16 +14,16 @@
 # under the License.
 from oslo_log import log
 
-from vitrage.common.constants import EntityCategory
+from vitrage.common.constants import EntityCategory as ECategory
 from vitrage.common.constants import GraphAction
 from vitrage.common.constants import VertexProperties as VProps
 from vitrage.datasources.transformer_base import TransformerBase
 from vitrage.entity_graph.mappings.datasource_info_mapper import \
     DatasourceInfoMapper
 from vitrage.entity_graph.processor import base as processor
-from vitrage.entity_graph.processor.notifier import GraphNotifier
 from vitrage.entity_graph.processor import processor_utils as PUtils
-from vitrage.entity_graph.transformer_manager import TransformerManager
+from vitrage.entity_graph.processor.transformer_manager import \
+    TransformerManager
 from vitrage.graph import Direction
 
 LOG = log.getLogger(__name__)
@@ -31,17 +31,13 @@ LOG = log.getLogger(__name__)
 
 class Processor(processor.ProcessorBase):
 
-    def __init__(self, conf, initialization_status, e_graph,
-                 graph_persistor=None):
+    def __init__(self, conf, e_graph=None):
         super(Processor, self).__init__()
         self.conf = conf
         self.transformer_manager = TransformerManager(self.conf)
-        self.state_manager = DatasourceInfoMapper(self.conf)
+        self.info_mapper = DatasourceInfoMapper(self.conf)
         self._initialize_events_actions()
-        self.initialization_status = initialization_status
         self.entity_graph = e_graph
-        self._notifier = GraphNotifier(conf)
-        self._graph_persistor = graph_persistor
 
     def process_event(self, event):
         """Decides which action to run on given event
@@ -58,10 +54,14 @@ class Processor(processor.ProcessorBase):
 
         self._enrich_event(event)
         entity = self.transformer_manager.transform(event)
-        self._calculate_vitrage_aggregated_state(entity.vertex, entity.action)
+
+        if entity.action not in self.actions.keys():
+            LOG.debug('deprecated or unknown entity %s ignored', str(entity))
+            return
+
+        self._calculate_vitrage_aggregated_values(entity.vertex, entity.action)
+        self._set_datasource_name(entity, event)
         self.actions[entity.action](entity.vertex, entity.neighbors)
-        if self._graph_persistor:
-            self._graph_persistor.update_last_event_timestamp(event)
 
     def create_entity(self, new_vertex, neighbors):
         """Adds new vertex to the entity graph
@@ -76,7 +76,6 @@ class Processor(processor.ProcessorBase):
         """
 
         LOG.debug('Add entity to entity graph:\n%s', new_vertex)
-
         self._add_resource_details_to_alarm(new_vertex, neighbors)
         self.entity_graph.add_vertex(new_vertex)
         self._connect_neighbors(neighbors, set(), GraphAction.CREATE_ENTITY)
@@ -140,7 +139,7 @@ class Processor(processor.ProcessorBase):
 
             PUtils.mark_deleted(self.entity_graph, deleted_vertex)
         else:
-            LOG.warning("Delete event arrived on invalid resource: "
+            LOG.warning("Delete entity arrived on invalid resource: "
                         "deleted_vertex - %s, graph_vertex - %s",
                         deleted_vertex, graph_vertex)
 
@@ -184,18 +183,10 @@ class Processor(processor.ProcessorBase):
                 PUtils.is_newer_vertex(graph_vertex, vertex):
             self.entity_graph.remove_vertex(vertex)
         else:
-            LOG.warning("Delete event arrived on invalid resource: "
+            LOG.warning("Remove deleted entity arrived on invalid resource: "
                         "deleted_vertex - %s, graph_vertex - %s",
                         vertex, graph_vertex)
 
-    def handle_end_message(self, vertex, neighbors):
-        self.initialization_status.handle_end_message(vertex)
-
-    def on_recieved_all_end_messages(self):
-        if self._notifier and self._notifier.enabled:
-            self.entity_graph.subscribe(self._notifier.notify_when_applicable)
-            LOG.info('Graph notifications subscription added')
-
     def _update_neighbors(self, vertex, neighbors):
         """Updates vertices neighbor connections
 
@@ -221,11 +212,12 @@ class Processor(processor.ProcessorBase):
         for (vertex, edge) in neighbors:
             graph_vertex = self.entity_graph.get_vertex(vertex.vertex_id)
             if not graph_vertex or not PUtils.is_deleted(graph_vertex):
-                LOG.debug("Updates vertex: %s", vertex)
-                self._calculate_vitrage_aggregated_state(vertex, action)
-                PUtils.update_entity_graph_vertex(self.entity_graph,
-                                                  graph_vertex,
-                                                  vertex)
+                if PUtils.can_update_vertex(graph_vertex, vertex):
+                    LOG.debug("Updates vertex: %s", vertex)
+                    self._calculate_vitrage_aggregated_values(vertex, action)
+                    PUtils.update_entity_graph_vertex(self.entity_graph,
+                                                      graph_vertex,
+                                                      vertex)
 
                 if edge not in valid_edges:
                     LOG.debug("Updates edge: %s", edge)
@@ -269,7 +261,7 @@ class Processor(processor.ProcessorBase):
         neighbor_edges = set(e for v, e in neighbors)
         for curr_edge in self.entity_graph.get_edges(vertex.vertex_id,
                                                      direction=Direction.BOTH):
-            # check if the edge in the graph has a a connection to the
+            # check if the edge in the graph has a connection to the
             # same type of resources in the new neighbors list
             neighbor_vertex = self.entity_graph.get_vertex(
                 curr_edge.other_vertex(vertex.vertex_id))
@@ -296,11 +288,9 @@ class Processor(processor.ProcessorBase):
             GraphAction.UPDATE_RELATIONSHIP: self.update_relationship,
             GraphAction.DELETE_RELATIONSHIP: self.delete_relationship,
             GraphAction.REMOVE_DELETED_ENTITY: self.remove_deleted_entity,
-            # should not be called explicitly
-            GraphAction.END_MESSAGE: self.handle_end_message
         }
 
-    def _calculate_vitrage_aggregated_state(self, vertex, action):
+    def _calculate_vitrage_aggregated_values(self, vertex, action):
         LOG.debug("calculate event state")
 
         try:
@@ -319,9 +309,9 @@ class Processor(processor.ProcessorBase):
                           action, vertex)
                 return None
 
-            self.state_manager.vitrage_aggregated_state(vertex, graph_vertex)
-        except Exception as e:
-            LOG.exception("Calculate aggregated state failed - %s", e)
+            self.info_mapper.vitrage_aggregate_values(vertex, graph_vertex)
+        except Exception:
+            LOG.exception("Calculate aggregated state failed.")
 
     def _enrich_event(self, event):
         attr = self.transformer_manager.get_enrich_query(event)
@@ -330,22 +320,52 @@ class Processor(processor.ProcessorBase):
         result = self.entity_graph.get_vertices(attr)
         event[TransformerBase.QUERY_RESULT] = result
 
-    @staticmethod
-    def _add_resource_details_to_alarm(vertex, neighbors):
+    def _add_resource_details_to_alarm(self, vertex, neighbors):
 
-        if not vertex.get(VProps.VITRAGE_CATEGORY) == EntityCategory.ALARM \
-                or not neighbors:
+        if not neighbors:
             return
 
-        # for the possibility that alarm doesn't have resource
-        vertex.properties[VProps.VITRAGE_RESOURCE_ID] = None
-        vertex.properties[VProps.VITRAGE_RESOURCE_TYPE] = None
+        resource = None
+        alarms = []
 
-        for neighbor in neighbors:
+        if vertex.get(VProps.VITRAGE_CATEGORY) == ECategory.ALARM:
+            alarms = [vertex]
+            for neighbor in neighbors:
+                if neighbor.vertex.get(VProps.VITRAGE_CATEGORY) ==\
+                        ECategory.RESOURCE:
+                    resource = neighbor.vertex
+        elif vertex.get(VProps.VITRAGE_CATEGORY) == ECategory.RESOURCE:
+            resource = vertex
+            for neighbor in neighbors:
+                if neighbor.vertex.get(VProps.VITRAGE_CATEGORY) == \
+                        ECategory.ALARM:
+                    alarms.append(neighbor.vertex)
 
-            if neighbor.vertex.get(VProps.VITRAGE_CATEGORY) == \
-                    EntityCategory.RESOURCE:
-                vertex.properties[VProps.VITRAGE_RESOURCE_ID] = \
-                    neighbor.vertex.vertex_id
-                vertex.properties[VProps.VITRAGE_RESOURCE_TYPE] = \
-                    neighbor.vertex.get(VProps.VITRAGE_TYPE)
+        for alarm in alarms:
+            if not resource:
+                continue
+
+            project_id = resource.get(VProps.PROJECT_ID)
+            if not project_id:
+                n_vertex = self.entity_graph.get_vertex(resource.vertex_id)
+                project_id = n_vertex.get(VProps.PROJECT_ID) \
+                    if n_vertex else None
+            self.add_resource_details(
+                alarm,
+                r_id=resource.vertex_id,
+                r_type=resource.get(VProps.VITRAGE_TYPE),
+                r_project_id=project_id)
+
+    @staticmethod
+    def add_resource_details(alarm, r_id, r_type, r_project_id):
+        alarm[VProps.VITRAGE_RESOURCE_ID] = r_id
+        alarm[VProps.VITRAGE_RESOURCE_TYPE] = r_type
+        if r_project_id:
+            alarm[VProps.VITRAGE_RESOURCE_PROJECT_ID] = r_project_id
+
+    @staticmethod
+    def _set_datasource_name(entity, event):
+        if entity.vertex and entity.action == GraphAction.CREATE_ENTITY:
+            datasource_name = event.get(VProps.VITRAGE_DATASOURCE_NAME)
+            entity.vertex.properties[VProps.VITRAGE_DATASOURCE_NAME] = \
+                datasource_name
