@@ -132,22 +132,29 @@ class NXAlgorithm(GraphAlgorithm):
                                             query_dict=None,
                                             edge_attr_filter=None):
         if query_dict:
-            vertices = self.graph.vertices_iter(query_dict=query_dict)
+            vertices = self.graph.get_vertices(query_dict=query_dict)
         elif vertex_attr_filter:
-            vertices = self.graph.vertices_iter(
+            vertices = self.graph.get_vertices(
                 vertex_attr_filter=vertex_attr_filter)
         else:
-            vertices = self.graph.vertices_iter()
+            vertices = self.graph.get_vertices()
 
-        vertices_ids = (vertex.vertex_id for vertex in vertices)
+        vertices_ids = [vertex.vertex_id for vertex in vertices]
 
         graph = self._create_new_graph('graph')
-        graph._g = self.graph._g.subgraph(vertices_ids)
+        graph._g = self.graph._g.subgraph(vertices_ids).copy()
 
         # delete non matching edges
         if edge_attr_filter:
             self._apply_edge_attr_filter(graph, edge_attr_filter)
 
+        LOG.debug('match query, find graph: nodes %s, edges %s',
+                  str(list(graph._g.nodes(data=True))),
+                  str(list(graph._g.edges(data=True))))
+        LOG.debug('match query, real graph: nodes %s, edges %s',
+                  str(list(self.graph._g.nodes(data=True))),
+                  str(list(self.graph._g.edges(data=True))))
+
         return graph
 
     def subgraph(self, entities):
@@ -186,19 +193,18 @@ class NXAlgorithm(GraphAlgorithm):
 
     @staticmethod
     def _edge_result_to_list(edge_result):
-        keys = set()
+        d = dict()
         for source_id, target_id, label, data in edge_result:
-            if (source_id, target_id, label) not in keys:
-                keys.add((source_id, target_id, label))
-                yield Edge(source_id, target_id, label, properties=data)
+            d[(source_id, target_id, label)] = \
+                Edge(source_id, target_id, label, properties=data)
+        return d.values()
 
     @staticmethod
     def _vertex_result_to_list(vertex_result):
-        keys = set()
+        d = dict()
         for v_id, data in vertex_result:
-            if v_id not in keys:
-                keys.add(v_id)
-                yield Vertex(vertex_id=v_id, properties=data)
+            d[v_id] = Vertex(vertex_id=v_id, properties=data)
+        return d.values()
 
     @staticmethod
     def _list_union(list_1, list_2):
@@ -218,8 +224,8 @@ class NXAlgorithm(GraphAlgorithm):
 
     @staticmethod
     def _apply_edge_attr_filter(graph, edge_attr_filter):
-        edges_iter = graph._g.edges_iter(data=True, keys=True)
-        edges_to_remove = [(u, v, k) for (u, v, k, d) in edges_iter
+        edges = graph._g.edges(data=True, keys=True)
+        edges_to_remove = [(u, v, k) for (u, v, k, d) in edges
                            if not check_filter(d, edge_attr_filter)]
         for source, target, key in edges_to_remove:
             graph._g.remove_edge(u=source, v=target, key=key)
