@@ -49,8 +49,25 @@ class Graph(object):
         self.graph_type = graph_type
         self.notifier = Notifier()
 
-    def subscribe(self, function):
-        self.notifier.subscribe(function)
+    def subscribe(self, function, finalization=False):
+        """Subscribe to graph changes
+
+        :param function: function will be called after each graph change
+        :param finalization: function will be called after all non finalization
+
+        Usage Example:
+        graph = NXGraph()
+        graph.subscribe(foo1, finalization=True)
+        graph.subscribe(foo2, finalization=False)
+        graph.subscribe(foo3, finalization=False)
+
+        The order of the calls in this example wii be:
+        1. foo2
+        2. foo3
+        3. foo1
+        foo1 is called last because it subscribed as a finalization function
+        """
+        self.notifier.subscribe(function, finalization)
 
     def is_subscribed(self):
         return self.notifier.is_subscribed()
@@ -242,16 +259,13 @@ class Graph(object):
         pass
 
     @abc.abstractmethod
-    def update_vertex(self, v, overwrite=True):
+    def update_vertex(self, v):
         """Update the vertex properties
 
         Update an existing vertex and create it if non existing.
 
         :param v: the vertex with the new data
         :type v: Vertex
-
-        :param overwrite: whether to overwrite existing vertices
-        :type overwrite: Boolean
         """
         pass
 
@@ -279,13 +293,11 @@ class Graph(object):
         pass
 
     @staticmethod
-    def _merge_properties(base_props, new_props, overwrite):
+    def _merge_properties(base_props, new_props):
         if base_props is None:
             base_props = copy.copy(new_props)
         else:
-            # Copy new properties, and optionally overwrite the old properties
-            base_props.update({k: v for k, v in new_props.items() if
-                               overwrite or k not in base_props})
+            base_props.update(copy.copy(new_props))
         return {k: v for k, v in base_props.items() if v is not None}
 
     @abc.abstractmethod
