@@ -13,9 +13,11 @@
 # under the License.
 
 import copy
+import json
 import networkx as nx
 from networkx.algorithms.operators.binary import compose
 from networkx.readwrite import json_graph
+from six.moves import cPickle
 
 from oslo_log import log as logging
 
@@ -63,9 +65,9 @@ class NXGraph(Graph):
 
     def copy(self):
         # Networkx graph copy is very slow, so we implement
-        nodes = self._g.nodes_iter(data=True)
+        nodes = self._g.nodes(data=True)
         vertices = [Vertex(vertex_id=n, properties=data) for n, data in nodes]
-        edges_iter = self._g.edges_iter(data=True, keys=True)
+        edges_iter = self._g.edges(data=True, keys=True)
         edges = [Edge(source_id=u, target_id=v, label=l, properties=data)
                  for u, v, l, data in edges_iter]
         return NXGraph(self.name, vertices, edges)
@@ -81,7 +83,10 @@ class NXGraph(Graph):
 
     def _add_vertex(self, v):
         properties_copy = copy.copy(v.properties)
-        self._g.add_node(n=v.vertex_id, attr_dict=properties_copy)
+        if properties_copy:
+            self._g.add_node(v.vertex_id, **properties_copy)
+        else:
+            self._g.add_node(v.vertex_id)
 
     @Notifier.update_notify
     def add_edge(self, e):
@@ -94,8 +99,11 @@ class NXGraph(Graph):
 
     def _add_edge(self, e):
         properties_copy = copy.copy(e.properties)
-        self._g.add_edge(u=e.source_id, v=e.target_id,
-                         key=e.label, attr_dict=properties_copy)
+        if properties_copy:
+            self._g.add_edge(e.source_id, e.target_id,
+                             e.label, **properties_copy)
+        else:
+            self._g.add_edge(e.source_id, e.target_id, e.label)
 
     def get_vertex(self, v_id):
         """Fetch a vertex from the graph
@@ -165,7 +173,7 @@ class NXGraph(Graph):
         return self._g.number_of_edges()
 
     @Notifier.update_notify
-    def update_vertex(self, v, overwrite=True):
+    def update_vertex(self, v):
         """Update the vertex properties
 
         :type v: Vertex
@@ -174,8 +182,10 @@ class NXGraph(Graph):
         if not orig_prop:
             self._add_vertex(v)
             return
-        new_prop = self._merge_properties(orig_prop, v.properties, overwrite)
-        self._g.node[v.vertex_id] = new_prop
+        self._g.node[v.vertex_id].update(v.properties)
+        for prop, value in v.properties.items():
+            if value is None:
+                del self._g.node[v.vertex_id][prop]
 
     @Notifier.update_notify
     def update_edge(self, e):
@@ -183,15 +193,17 @@ class NXGraph(Graph):
 
         :type e: Edge
         """
-        orig_prop = self._g.edge.get(
+        orig_prop = self._g.adj.get(
             e.source_id, {}).get(
             e.target_id, {}).get(
             e.label, None)
         if not orig_prop:
             self._add_edge(e)
             return
-        new_prop = self._merge_properties(orig_prop, e.properties, True)
-        self._g.edge[e.source_id][e.target_id][e.label] = new_prop
+        self._g.adj[e.source_id][e.target_id][e.label].update(e.properties)
+        for prop, value in e.properties.items():
+            if value is None:
+                del self._g.adj[e.source_id][e.target_id][e.label][prop]
 
     def remove_vertex(self, v):
         """Remove Vertex v and its edges from the graph
@@ -215,12 +227,12 @@ class NXGraph(Graph):
             return check_filter(vertex_data[1], vertex_attr_filter)
 
         if not query_dict:
-            items = filter(check_vertex, self._g.nodes_iter(data=True))
+            items = filter(check_vertex, list(self._g.nodes(data=True)))
             return [vertex_copy(node, node_data) for node, node_data in items]
         elif not vertex_attr_filter:
             vertices = []
             match_func = create_predicate(query_dict)
-            for node, node_data in self._g.nodes_iter(data=True):
+            for node, node_data in list(self._g.nodes(data=True)):
                 v = vertex_copy(node, node_data)
                 if match_func(v):
                     vertices.append(v)
@@ -228,17 +240,6 @@ class NXGraph(Graph):
         else:
             return []
 
-    def vertices_iter(self, vertex_attr_filter=None, query_dict=None):
-        if not query_dict:
-            for n, data in list(self._g.nodes_iter(data=True)):
-                if check_filter(data, vertex_attr_filter):
-                    yield vertex_copy(n, data)
-        elif not vertex_attr_filter:
-            match_func = create_predicate(query_dict)
-            for n, data in list(self._g.nodes_iter(data=True)):
-                if match_func(data):
-                    yield vertex_copy(n, data)
-
     def get_vertices_by_key(self, key_values_hash):
 
         if key_values_hash in self.key_to_vertex_ids:
@@ -293,23 +294,49 @@ class NXGraph(Graph):
         return nodes, edges_filtered2
 
     def json_output_graph(self, **kwargs):
+        """supports both 1.10<=networkx<2.0 and networx>=2.0 by returning the
+
+        same json output regardless networx version
+
+        :return: graph in json format
+        """
+
+        # TODO(annarez): when we decide to support networkx 2.0 with
+        # versioning of Vitrage, we can move part of the logic to vitrageclient
         node_link_data = json_graph.node_link_data(self._g)
         node_link_data.update(kwargs)
 
+        vitrage_id_to_index = dict()
+
         for index, node in enumerate(node_link_data['nodes']):
+            vitrage_id_to_index[node[VProps.VITRAGE_ID]] = index
             if VProps.ID in self._g.node[node[VProps.ID]]:
                 node[VProps.ID] = self._g.node[node[VProps.ID]][VProps.ID]
                 node[VProps.GRAPH_INDEX] = index
 
-        return node_link_data
+        vers = nx.__version__
+        if vers >= '2.0':
+            for i in range(len(node_link_data['links'])):
+                node_link_data['links'][i]['source'] = vitrage_id_to_index[
+                    node_link_data['links'][i]['source']]
+                node_link_data['links'][i]['target'] = vitrage_id_to_index[
+                    node_link_data['links'][i]['target']]
 
-    def to_json(self):
-        return json_graph.node_link_data(self._g)
+        if kwargs.get('raw', False):
+            return node_link_data
+        else:
+            return json.dumps(node_link_data)
+
+    def write_gpickle(self):
+        return cPickle.dumps(self._g, cPickle.HIGHEST_PROTOCOL)
 
     @staticmethod
-    def from_json(data):
-        graph = NXGraph()
-        graph._g = nx.MultiDiGraph(json_graph.node_link_graph(data))
+    def read_gpickle(data, graph_to_update=None):
+        if graph_to_update is not None:
+            graph = graph_to_update
+        else:
+            graph = NXGraph()
+        graph._g = cPickle.loads(data)
         return graph
 
     def union(self, other_graph):
