@@ -56,6 +56,7 @@ DRIVER_INST_SNAPSHOT_S = 'driver_inst_snapshot_static.json'
 DRIVER_INST_UPDATE_D = 'driver_inst_update_dynamic.json'
 DRIVER_NAGIOS_SNAPSHOT_D = 'driver_nagios_snapshot_dynamic.json'
 DRIVER_NAGIOS_SNAPSHOT_S = 'driver_nagios_snapshot_static.json'
+DRIVER_PROMETHEUS_UPDATE_D = 'driver_prometheus_update_dynamic.json'
 DRIVER_ZABBIX_SNAPSHOT_D = 'driver_zabbix_snapshot_dynamic.json'
 DRIVER_SWITCH_SNAPSHOT_D = 'driver_switch_snapshot_dynamic.json'
 DRIVER_STATIC_SNAPSHOT_D = 'driver_static_snapshot_dynamic.json'
@@ -66,6 +67,7 @@ DRIVER_STACK_UPDATE_D = 'driver_stack_update_dynamic.json'
 DRIVER_STACK_SNAPSHOT_D = 'driver_stack_snapshot_dynamic.json'
 DRIVER_CONSISTENCY_UPDATE_D = 'driver_consistency_update_dynamic.json'
 DRIVER_ZONE_SNAPSHOT_D = 'driver_zone_snapshot_dynamic.json'
+DRIVER_KUBE_SNAPSHOT_D = 'driver_kubernetes_snapshot_dynamic.json'
 
 
 # Mock transformer Specs (i.e., what the transformer outputs)
@@ -75,6 +77,7 @@ TRANS_AODH_SNAPSHOT_D = 'transformer_aodh_snapshot_dynamic.json'
 TRANS_AODH_UPDATE_D = 'transformer_aodh_update_dynamic.json'
 TRANS_DOCTOR_UPDATE_D = 'transformer_doctor_update_dynamic.json'
 TRANS_COLLECTD_UPDATE_D = 'transformer_collectd_update_dynamic.json'
+TRANS_PROMETHEUS_UPDATE_D = 'transformer_prometheus_update_dynamic.json'
 TRANS_INST_SNAPSHOT_D = 'transformer_inst_snapshot_dynamic.json'
 TRANS_INST_SNAPSHOT_S = 'transformer_inst_snapshot_static.json'
 TRANS_HOST_SNAPSHOT_D = 'transformer_host_snapshot_dynamic.json'
@@ -117,8 +120,9 @@ class EventTraceGenerator(object):
 
         static_info_parsers = \
             {DRIVER_AODH_UPDATE_D: _get_aodh_alarm_update_driver_values,
-             DRIVER_DOCTOR_UPDATE_D: _get_doctor_update_driver_values,
-             DRIVER_COLLECTD_UPDATE_D: _get_collectd_update_driver_values,
+             DRIVER_DOCTOR_UPDATE_D: _get_simple_update_driver_values,
+             DRIVER_COLLECTD_UPDATE_D: _get_simple_update_driver_values,
+             DRIVER_KUBE_SNAPSHOT_D: _get_k8s_node_snapshot_driver_values,
              DRIVER_INST_SNAPSHOT_D: _get_vm_snapshot_driver_values,
              DRIVER_INST_UPDATE_D: _get_vm_update_driver_values,
              DRIVER_HOST_SNAPSHOT_D: _get_host_snapshot_driver_values,
@@ -133,11 +137,13 @@ class EventTraceGenerator(object):
              DRIVER_ZABBIX_SNAPSHOT_D: _get_zabbix_alarm_driver_values,
              DRIVER_CONSISTENCY_UPDATE_D:
                  _get_consistency_update_driver_values,
+             DRIVER_PROMETHEUS_UPDATE_D: _get_simple_update_driver_values,
 
              TRANS_AODH_SNAPSHOT_D: _get_trans_aodh_alarm_snapshot_values,
              TRANS_AODH_UPDATE_D: _get_trans_aodh_alarm_snapshot_values,
-             TRANS_DOCTOR_UPDATE_D: _get_trans_doctor_alarm_update_values,
-             TRANS_COLLECTD_UPDATE_D: _get_trans_collectd_alarm_update_values,
+             TRANS_DOCTOR_UPDATE_D: _get_simple_trans_alarm_update_values,
+             TRANS_COLLECTD_UPDATE_D: _get_simple_trans_alarm_update_values,
+             TRANS_PROMETHEUS_UPDATE_D: _get_simple_trans_alarm_update_values,
              TRANS_INST_SNAPSHOT_D: _get_trans_vm_snapshot_values,
              TRANS_HOST_SNAPSHOT_D: _get_trans_host_snapshot_values,
              TRANS_ZONE_SNAPSHOT_D: _get_trans_zone_snapshot_values}
@@ -247,7 +253,7 @@ def _get_host_snapshot_driver_values(spec):
     static_values = []
     for host_name, zone_name in host_zone_mapping:
 
-        mapping = {'host_name': host_name,
+        mapping = {'host': host_name,
                    'zone': zone_name,
                    '_info': {'host_name': host_name,
                              'zone': zone_name}}
@@ -257,19 +263,26 @@ def _get_host_snapshot_driver_values(spec):
     return static_values
 
 
-def _get_doctor_update_driver_values(spec):
-    """Generates the static driver values for Doctor monitor notification.
+def _get_k8s_node_snapshot_driver_values(spec):
+    """Generates the static driver values for each k8s node.
 
     :param spec: specification of event generation.
     :type spec: dict
-    :return: list of notifications of Doctor monitor
+    :return: list of static driver values for each k8s node.
     :rtype: list
     """
-    return [combine_data(None, None, spec.get(EXTERNAL_INFO_KEY, None))]
+
+    vm_host_mapping = spec[MAPPING_KEY]
+    static_values = []
+    for node_name in vm_host_mapping:
+        static_values.append(combine_data(node_name, None,
+                                          spec.get(EXTERNAL_INFO_KEY)))
+
+    return static_values
 
 
-def _get_collectd_update_driver_values(spec):
-    """Generates the static driver values for Collectd monitor notification.
+def _get_simple_update_driver_values(spec):
+    """Generates the static driver values for Doctor monitor notification.
 
     :param spec: specification of event generation.
     :type spec: dict
@@ -748,12 +761,12 @@ def _get_aodh_alarm_update_driver_values(spec):
     return static_values
 
 
-def _get_trans_doctor_alarm_update_values(spec):
-    """Generates the dynamic transformer values for a Doctor alarm
+def _get_simple_trans_alarm_update_values(spec):
+    """Generates the dynamic transformer values for a simple alarm
 
     :param spec: specification of event generation.
     :type spec: dict
-    :return: list of dynamic transformer values for a Doctor alarm
+    :return: list of dynamic transformer values for a simple alarm
     :rtype: list with one alarm
     """
 
@@ -765,23 +778,6 @@ def _get_trans_doctor_alarm_update_values(spec):
                          None, spec.get(EXTERNAL_INFO_KEY, None))]
 
 
-def _get_trans_collectd_alarm_update_values(spec):
-    """Generates the dynamic transformer values for a Collectd alarm
-
-    :param spec: specification of event generation.
-    :type spec: dict
-    :return: list of dynamic transformer values for a Collectd alarm
-    :rtype: list with one alarm
-    """
-
-    static_info = None
-    if spec[STATIC_INFO_FKEY] is not None:
-        static_info = utils.load_specs(spec[STATIC_INFO_FKEY])
-
-    return [combine_data(static_info,
-                         None, spec.get(EXTERNAL_INFO_KEY, None))]
-
-
 def combine_data(static_info, mapping_info, external_info):
     if external_info:
         mapping_info = utils.merge_vals(mapping_info, external_info)
