@@ -13,6 +13,7 @@
 # under the License.
 
 from oslo_config import cfg
+from testtools import matchers
 
 from vitrage.common.constants import DatasourceAction as DSAction
 from vitrage.common.constants import DatasourceProperties as DSProps
@@ -321,7 +322,7 @@ class TestProcessor(TestEntityGraphUnitBase):
         # action
         # state already exists and its updated
         instances[0][0][VProps.STATE] = 'SUSPENDED'
-        instances[0][1]._calculate_vitrage_aggregated_state(
+        instances[0][1]._calculate_vitrage_aggregated_values(
             instances[0][0], GraphAction.UPDATE_ENTITY)
 
         # vitrage state doesn't exist and its updated
@@ -329,13 +330,13 @@ class TestProcessor(TestEntityGraphUnitBase):
         instances[1][1].entity_graph.update_vertex(instances[1][0])
         instances[1][0][VProps.VITRAGE_STATE] = \
             OperationalResourceState.SUBOPTIMAL
-        instances[1][1]._calculate_vitrage_aggregated_state(
+        instances[1][1]._calculate_vitrage_aggregated_values(
             instances[1][0], GraphAction.UPDATE_ENTITY)
 
         # state exists and vitrage state changes
         instances[2][0][VProps.VITRAGE_STATE] = \
             OperationalResourceState.SUBOPTIMAL
-        instances[2][1]._calculate_vitrage_aggregated_state(
+        instances[2][1]._calculate_vitrage_aggregated_values(
             instances[2][0], GraphAction.UPDATE_ENTITY)
 
         # vitrage state exists and state changes
@@ -344,7 +345,7 @@ class TestProcessor(TestEntityGraphUnitBase):
             OperationalResourceState.SUBOPTIMAL
         instances[3][1].entity_graph.update_vertex(instances[3][0])
         instances[3][0][VProps.STATE] = 'SUSPENDED'
-        instances[3][1]._calculate_vitrage_aggregated_state(
+        instances[3][1]._calculate_vitrage_aggregated_values(
             instances[3][0], GraphAction.UPDATE_ENTITY)
 
         # state and vitrage state exists and state changes
@@ -352,14 +353,14 @@ class TestProcessor(TestEntityGraphUnitBase):
             OperationalResourceState.SUBOPTIMAL
         instances[4][1].entity_graph.update_vertex(instances[4][0])
         instances[4][0][VProps.STATE] = 'SUSPENDED'
-        instances[4][1]._calculate_vitrage_aggregated_state(
+        instances[4][1]._calculate_vitrage_aggregated_values(
             instances[4][0], GraphAction.UPDATE_ENTITY)
 
         # state and vitrage state exists and vitrage state changes
         instances[5][0][VProps.VITRAGE_STATE] = \
             OperationalResourceState.SUBOPTIMAL
         instances[5][1].entity_graph.update_vertex(instances[5][0])
-        instances[5][1]._calculate_vitrage_aggregated_state(
+        instances[5][1]._calculate_vitrage_aggregated_values(
             instances[5][0], GraphAction.UPDATE_ENTITY)
 
         # test assertions
@@ -408,7 +409,8 @@ class TestProcessor(TestEntityGraphUnitBase):
                      num_vertices,
                      num_edges,
                      vertex_id=None):
-        self.assertEqual(num_vertices, len(processor.entity_graph))
+        self.assertThat(processor.entity_graph,
+                        matchers.HasLength(num_vertices))
 
         if not vertex_id:
             self.assertEqual(num_edges, processor.entity_graph.num_edges())
